==> openGion_dev_5.0.1.0.zip: opengion/uap/webapps/ge/db/oracle/sql/01_TABLE/GE54S.sql <==
/**************************************************************************/
/* GE54 ( 帳票定義マスタ )                                                */
/*                                                                        */
/* Created : 2009/09/30 19:57:41                                          */
/**************************************************************************/
CREATE TABLE GE54 (
   SYSTEM_ID     VARCHAR2(10)                  NOT NULL      /* 10  システムID               */
 , LISTID        VARCHAR2(10)                  NOT NULL      /* 20  帳票ID                   */
 , LISTNAME      VARCHAR2(100)                               /* 30  帳票名称                 */
 , MODELDIR      VARCHAR2(100)                 NOT NULL      /* 40  雛型ファイルDIR          */
 , MODELFILE     VARCHAR2(20)                  NOT NULL      /* 50  雛型ファイル名           */
 , FGCUT         VARCHAR2(1)                                 /* 60  ページエンドカットフラグ */
 , HSQL          VARCHAR2(4000)                              /* 70  ヘッダーSQL              */
 , FSQL          VARCHAR2(4000)                              /* 80  フッターSQL              */
 , BSQL          VARCHAR2(4000)                              /* 90  ボディSQL                */
 , COMMENTS      VARCHAR2(500)                               /* 100 コメント                 */
 , FGJ           VARCHAR2(1)       DEFAULT '1' NOT NULL      /* 110 状態フラグ               */
 , DYSET         VARCHAR2(14)                                /* 120 登録日時                 */
 , DYUPD         VARCHAR2(14)                                /* 130 更新日時                 */
 , USRSET        VARCHAR2(10)                                /* 140 作成社員                 */
 , USRUPD        VARCHAR2(10)                                /* 150 更新者                   */
 , PRGUPD        VARCHAR2(10)                                /* 160 更新PRG                  */
 , FGLOCAL       VARCHAR2(1)       DEFAULT '0' NOT NULL      /* 170 ローカルリソース         */
 , FGDIRECT      VARCHAR2(1)       DEFAULT '0' NOT NULL      /* 180 ダイレクト               */
 , RELEASE_NOTES VARCHAR2(120)                               /* 190 リリースノート           */
 , RDC_CODE      VARCHAR2(20)                                /* 200 設変番号                 */
)
TABLESPACE GETBL01
STORAGE( INITIAL 256K NEXT 16K PCTINCREASE 0 );

==> openGion_dev_5.1.1.2.zip: opengion/uap/webapps/ge/db/oracle/sql/01_TABLE/GE54S.sql <==
/**************************************************************************/
/* GE54 ( 帳票定義マスタ )                                                */
/*                                                                        */
/* Created : 2009/12/10 12:29:41                                          */
/**************************************************************************/
CREATE TABLE GE54 (
   SYSTEM_ID     VARCHAR2(10)                  NOT NULL      /* 10  システムID               */
 , LISTID        VARCHAR2(10)                  NOT NULL      /* 20  帳票ID                   */
 , LISTNAME      VARCHAR2(100)                               /* 30  帳票名称                 */
 , MODELDIR      VARCHAR2(100)                 NOT NULL      /* 40  雛型ファイルDIR          */
 , MODELFILE     VARCHAR2(20)                  NOT NULL      /* 50  雛型ファイル名           */
 , FGCUT         VARCHAR2(1)                                 /* 60  ページエンドカットフラグ */
 , HSQL          VARCHAR2(4000)                              /* 70  ヘッダーSQL              */
 , FSQL          VARCHAR2(4000)                              /* 80  フッターSQL              */
 , BSQL          VARCHAR2(4000)                              /* 90  ボディSQL                */
 , COMMENTS      VARCHAR2(500)                               /* 100 コメント                 */
 , FGLOCAL       VARCHAR2(1)       DEFAULT '0' NOT NULL      /* 170 ローカルリソース         */
 , FGDIRECT      VARCHAR2(1)       DEFAULT '0' NOT NULL      /* 180 ダイレクト               */
 , RELEASE_NOTES VARCHAR2(120)                               /* 190 リリースノート           */
 , RDC_CODE      VARCHAR2(20)                                /* 200 設変番号                 */
 , FGJ           VARCHAR2(1)       DEFAULT '1' NOT NULL      /* 810 状態フラグ               */
 , DYSET         VARCHAR2(14)                                /* 820 登録日時                 */
 , PGSET         VARCHAR2(10)                                /* 830 作成PG                   */
 , PGPSET        VARCHAR2(10)                                /* 840 作成親PG                 */
 , USRSET        VARCHAR2(10)                                /* 850 作成社員                 */
 , DYUPD         VARCHAR2(14)                                /* 860 更新日時                 */
 , PGUPD         VARCHAR2(10)                                /* 870 更新PG                   */
 , PGPUPD        VARCHAR2(10)                                /* 880 更新親PG                 */
 , USRUPD        VARCHAR2(10)                                /* 890 更新者                   */
)
TABLESPACE GETBL01
STORAGE( INITIAL 256K NEXT 16K PCTINCREASE 0 );
